@@ -4,9 +4,9 @@
 
 ;; Author: Omar Polo <op@omarpolo.com>
 ;;         Timo Myyrä <timo.myyra@bittivirhe.fi>
-;; URL: https://git.omarpolo.com/vc-got/
+;; URL: https://projects.omarpolo.com/vc-got.html
 ;; Keywords: vc tools
-;; Version: 1.1
+;; Version: 1.1.1
 ;; Package-Requires: ((emacs "25.1"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -24,9 +24,9 @@
 
 ;;; Commentary:
 
-;; This file contains a VC backend for the Game of Trees (got) version
-;; control system.
-
+;; vc-got is a VC backend for the Game of Trees (got) version control
+;; system.
+;;
 ;; Backend implementation status
 ;;
 ;; Function marked with `*' are required, those with `-' are optional.
@@ -118,6 +118,8 @@
 ;; - conflicted-files                   DONE
 ;; - repository-url                     DONE
 
+;;; Code:
+
 ;; TODO: vc-git has most function that starts with:
 ;;
 ;;    (let* ((root (vc-git-root default-directory))
@@ -128,8 +130,6 @@
 ;; we should 1) investigate if also other backends do something like
 ;; this (or if there is a better way) and 2) try to do the same.
 
-;;; Code:
-
 (eval-when-compile
   (require 'subr-x))
 
@@ -663,12 +663,11 @@ It's like `vc-process-filter' but supports \r inside S."
 ;; be updated, either with a ``got update -b branch-name'' or ``got
 ;; update -b remote/branchname'' plus a rebase.
 (defun vc-got-pull (prompt)
-  "Execute a pull prompting for the full command if PROMPT is not nil."
+  "Execute a fetch prompting for the full command if PROMPT is not nil."
   (vc-got--push-pull vc-got-program "fetch" prompt))
 
 (defun vc-got-push (prompt)
-  "Run git push (not got!) in the repository dir.
-If PROMPT is non-nil, prompt for the git command to run."
+  "Execute a send prompting for the full command if PROMPT is not nil."
   (vc-got--push-pull vc-got-program "send" prompt))
 
 
